@@ -81,7 +81,6 @@
 #include "treeview.h"
 #include "stylesheet.h"
 #include "omcinteractiveenvironment.h"
-#include "indent.h"
 
 namespace IAEX {
   /*!
@@ -89,19 +88,13 @@ namespace IAEX {
   * clicks on the editor
   */
   MyTextEdit3::MyTextEdit3(QWidget *parent)
-    : QTextBrowser(parent),
-    inCommand(false),
-    autoIndent(true)
+    : QTextBrowser(parent)
   {
 
   }
 
   MyTextEdit3::~MyTextEdit3()
   {
-    for(QMap<int, IndentationState*>::iterator i = indentationStates.begin(); i != indentationStates.end(); ++i)
-    {
-      delete i.value();
-    }
   }
 
   /*!
@@ -110,7 +103,6 @@ namespace IAEX {
   */
   void MyTextEdit3::mousePressEvent(QMouseEvent *event)
   {
-    inCommand = false;
     QTextBrowser::mousePressEvent(event);
 
     if( event->modifiers() == Qt::ShiftModifier ||
@@ -155,8 +147,6 @@ namespace IAEX {
     if( event->modifiers() == Qt::ShiftModifier &&
       (event->key() == Qt::Key_Return || event->key() == Qt::Key_Enter) )
     {
-      inCommand = false;
-
       event->accept();
       emit eval();
     }
@@ -164,38 +154,28 @@ namespace IAEX {
     else if( event->key() == Qt::Key_Backspace ||
       event->key() == Qt::Key_Delete )
     {
-      inCommand = false;
-
       QTextBrowser::keyPressEvent( event );
     }
     // ALT+ENTER (ignore)
     else if( event->modifiers() == Qt::AltModifier &&
       ( event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return ))
     {
-      inCommand = false;
-
       event->ignore();
     }
     // PAGE UP (ignore)
     else if( event->key() == Qt::Key_PageUp )
     {
-      inCommand = false;
-
       event->ignore();
     }
     // PAGE DOWN (ignore)
     else if( event->key() == Qt::Key_PageDown )
     {
-      inCommand = false;
-
       event->ignore();
     }
     // CTRL+C
     else if( event->modifiers() == Qt::ControlModifier &&
       event->key() == Qt::Key_C )
     {
-      inCommand = false;
-
       event->ignore();
       emit forwardAction( 1 );
     }
@@ -203,8 +183,6 @@ namespace IAEX {
     else if( event->modifiers() == Qt::ControlModifier &&
       event->key() == Qt::Key_X )
     {
-      inCommand = false;
-
       event->ignore();
       emit forwardAction( 2 );
     }
@@ -212,29 +190,11 @@ namespace IAEX {
     else if( event->modifiers() == Qt::ControlModifier &&
       event->key() == Qt::Key_V )
     {
-      inCommand = false;
-
       event->ignore();
       emit forwardAction( 3 );
     }
-    else if(event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_W)
-    {
-      inCommand = false;
-      indentText();
-      event->ignore();
-      //      QTextBrowser::keyPressEvent( event );
-      //      update();
-
-    }
-
-    else if(event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_E)
-    {
-      inCommand = false;
-      indentText();
-    }
     else if(event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_K)
     {
-      inCommand = false;
       QTextCursor tc(textCursor());
       int i = toPlainText().indexOf(QRegExp("\\n|$"), tc.position());
 
@@ -249,73 +209,14 @@ namespace IAEX {
     // TAB
     else if( event->key() == Qt::Key_Tab )
     {
-      inCommand = false;
       textCursor().insertText( "  " );
     }
-    else if( event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return )
-    {
-      if(autoIndent)
-      {
-        QTextCursor t(textCursor());
-        QString tmp, tmp2;
-        int k2 = t.blockNumber();
-        QTextBlock b = t.block();
-        int k = b.userState();
-        int prevLevel = b.text().indexOf(QRegExp("\\S"));
-
-        while(k2 >= 0 && !indentationStates.contains(k))
-        {
-          tmp = b.text() + "\n" + tmp;
-          b = b.previous();
-          --k2;
-          k = b.userState();
-        }
-        Indent i(tmp);
-        if(indentationStates.contains(k))
-        {
-          IndentationState* s = indentationStates[k];
-          i.ism.level = s->level;
-          i.ism.equation = s->equation;
-          i.ism.equationSection = s->equationSection;
-          i.ism.lMod = s->lMod;
-          i.ism.loopBlock = s->loopBlock;
-          i.ism.nextMod = s->nextMod;
-          i.ism.skipNext = s->skipNext;
-          i.ism.state = s->state;
-          i.current = s->current;
-          i.next = s->next;
-        }
-
-        i.indentedText();
-
-        if(prevLevel > 2*i.level())
-        {
-          t.setPosition(t.block().position());
-          t.setPosition(t.block().position() + prevLevel-2*(i.level()),QTextCursor::KeepAnchor);
-          if(!t.selection().toPlainText().trimmed().size())
-            t.insertText("");
-          t.setPosition(t.block().position() + t.block().length() -1);
-        }
-
-        QTextBrowser::keyPressEvent(event);
-        t.insertText(QString(2*i.level(), ' '));
-      }
-      else
-        QTextBrowser::keyPressEvent(event);
-    }
     else
     {
-      inCommand = false;
       QTextBrowser::keyPressEvent( event );
     }
 
     updatePosition();
-
-  }
-
-  void MyTextEdit3::setAutoIndent(bool b)
-  {
-    autoIndent = b;
   }
 
   void MyTextEdit3::setModified()
@@ -352,35 +253,6 @@ namespace IAEX {
       emit setState(Modified_l);
   }
 
-  void MyTextEdit3::goToPos(const QUrl& u)
-  {
-    QRegExp e("\\-|:");
-    int r=u.toString().section(e, 0,0).toInt();
-    int c=u.toString().section(e, 1,1).toInt();
-    int r2=u.toString().section(e, 2,2).toInt();
-    int c2=u.toString().section(e, 3,3).toInt();
-
-    int p = 0;
-    for(int i = 1; i < r; ++i)
-      p = toPlainText().indexOf("\n", p)+1;
-    p += (c-1);
-
-    QTextCursor tc(textCursor());
-    tc.setPosition(p);
-
-    int p2 = 0;
-    if(r2 > 0)
-    {
-      for(int i = 1; i < r2; ++i)
-        p2 = toPlainText().indexOf("\n", p2)+1;
-      p2 += (c2-1);
-      tc.setPosition(p2, QTextCursor::KeepAnchor);
-    }
-    setTextCursor(tc);
-    updatePos(r, c);
-    setFocus(Qt::MouseFocusReason);
-  }
-
   void MyAction1::triggered2()
   {
     emit urlClicked(QUrl(text()));
@@ -410,10 +282,6 @@ namespace IAEX {
     createLatexCell();
     createOutputCell();
 
-    //connect(input_, SIGNAL(showVariableButton(bool)), this, SLOT(showVariableButton(bool)));
-
-    //connect(output_, SIGNAL(anchorClicked(const QUrl&)), input_, SLOT(goToPos(const QUrl&)));
-
     imageFile=0;
   }
 
@@ -501,40 +369,6 @@ namespace IAEX {
     output_->hide();
   }
 
-  bool MyTextEdit3::lessIndented(QString s)
-  {
-    QRegExp l("\\b(equation|algorithm|public|protected|else|elseif)\\b");
-    return s.indexOf(l) >= 0;
-  }
-
-  int MyTextEdit3::indentationLevel(QString s, bool includeNegative)
-  {
-    QRegExp e1("\\b(model|class|type|connector|block|record|function|record|for|when|package|if)\\b");
-    QRegExp e1b("end\\s+(model|class|type|connector|block|record|function|record|for|when|package|if)\\b");
-    QRegExp e2("\\b(end|then)\\b");
-
-    QRegExp newLineEnd("^end\\b");
-
-    //    return s.count(e1) - includeNegative?(s.count(e2) + s.count(e1b)):0;
-    if(includeNegative)
-      return s.count(e1) - s.count(e2) - s.count(e1b);// - s.count(lessIndented);
-    else
-      return s.count(e1) - s.count(e1b);//- s.count(lessIndented);
-  }
-
-  void MyTextEdit3::indentText()
-  {
-    Indent a(toPlainText());
-    setText(a.indentedText(&indentationStates));
-
-    int i = 1;
-    for(QTextBlock b =this->document()->begin(); b != this->document()->end(); b = b.next())
-    {
-      b.setUserState(++i);
-    }
-    emit textChanged();
-  }
-
   /*!
   * \author Anders Fernström
   * \date 2006-04-21
@@ -558,8 +392,7 @@ namespace IAEX {
     else
     {
       // 2006-01-30 AF, add message box
-      QString msg = "No Output style defened, please define a Output style in stylesheet.xml";
-      QMessageBox::warning( 0, "Warning", msg, "OK" );
+      QMessageBox::warning( 0, tr("Warning"), tr("No Output style defined, please define an Output style in stylesheet.xml"), "OK" );
     }
 
     QTextCursor cursor = output_->textCursor();
@@ -822,7 +655,7 @@ namespace IAEX {
   QString LatexCell::ChapterCounter()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toPlainText();
   }
@@ -834,7 +667,7 @@ namespace IAEX {
   QString LatexCell::ChapterCounterHtml()
   {
     if( chaptercounter_->toPlainText().isEmpty() )
-      return QString::null;
+      return QString();
 
     return chaptercounter_->toHtml();
   }
@@ -1080,7 +913,7 @@ void LatexCell::eval(bool silent)
     {
         expr.replace("\\begin{document}","\\begin{document} \\thispagestyle{empty}");
         if (!expr.contains("\\begin{document}")) {
-            expr.prepend("\\documentclass[12pt]{article}\\usepackage{amsmath}\\usepackage{amsfonts}\\usepackage{amssymb}\\begin{document}\\thispagestyle{empty}");
+            expr.prepend("\\documentclass[12pt]{article}\\usepackage[utf8]{inputenc}\\usepackage{amsmath}\\usepackage{amsfonts}\\usepackage{amssymb}\\begin{document}\\thispagestyle{empty}");
             expr.append("\\end{document}");
         }
         QFile file(Tex);
@@ -1101,8 +934,9 @@ void LatexCell::eval(bool silent)
         /* Check for latex is installed */
         if (Latexversion.isEmpty())
         {
+          setState(Error_l);
           if (!silent)
-            QMessageBox::warning( 0, "Error", "Latex is not installed in your System. This cell cannot be evaluated.", "OK" );
+            QMessageBox::warning( 0, tr("Error"), tr("Latex is not installed in your System. This cell cannot be evaluated."), "OK" );
         }
         /*Generate the DVI file from tex through latex */
         else
@@ -1130,11 +964,13 @@ void LatexCell::eval(bool silent)
                 input_->clear();
                 input_->textCursor().insertText(texoutput);
                 setClosed(false);
+                setState(Error_l);
             }
             else
             {
                 setdvi=true;
                 setClosed(true);
+                setState(Finished_l);
             }
 
         }
@@ -1153,6 +989,7 @@ void LatexCell::eval(bool silent)
                     input_->clear();
                     input_->textCursor().insertText("Error:Problem in finding dvipng executable");
                     setClosed(false);
+                    setState(Error_l);
                 }
                 else
                 {
@@ -1167,8 +1004,7 @@ void LatexCell::eval(bool silent)
             }
             else
             {
-
-                QMessageBox::warning( 0, "Warning", "Maximum of 1 page document generation is supported per Latexcell, The script generates more than 1 page", "OK" );
+                QMessageBox::warning( 0, tr("Warning"), tr("Maximum of 1 page document generation is supported per Latexcell.\nThe script generates more than 1 page."), "OK" );
             }
         }
     }
@@ -1176,8 +1012,9 @@ void LatexCell::eval(bool silent)
     {
         //qDebug()<< "Empty cells can't be evaluated";
         input_->clear();
-        input_->textCursor().insertText("Message: Empty Latex Cells cannot be Evaluated");
+        input_->textCursor().insertText(tr("Message: Empty Latex Cells cannot be evaluated."));
         setClosed(false);
+        setState(Error_l);
     }
     input_->blockSignals(false);
     output_->blockSignals(false);
@@ -1190,16 +1027,16 @@ void LatexCell::setState(int state_)
     switch(state_)
     {
     case Modified_l:
-      emit newState("Ready");
+      emit newState(tr("Ready"));
       break;
     case Eval_l:
-      emit newState("Evaluating...");
+      emit newState(tr("Evaluating..."));
       break;
     case Finished_l:
-      emit newState("Done");
+      emit newState(tr("Done"));
       break;
     case Error_l:
-      emit newState("Error");
+      emit newState(tr("Error"));
       break;
     }
   }
